helper

package
v0.0.0-...-2db71d7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2021 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetLibp2pPeerIdFromCert

func GetLibp2pPeerIdFromCert(certPemBytes []byte) (string, error)

GetLibp2pPeerIdFromCert create a peer.ID with pubKey that contains in cert. 根据证书中的公钥生成一个libp2p的peer.ID。

func GetNodeUidFromAddr

func GetNodeUidFromAddr(addr string) (string, error)

GetNodeUidFromAddr get the unique id of node from a addr. 从地址中截取出节点ID

func P2pAddressFormatVerify

func P2pAddressFormatVerify(address string) bool

P2pAddressFormatVerify verify a node address format.

Types

This section is empty.

Source Files

  • net_helper.go

Directories

Path Synopsis
Package crypto implements various cryptographic utilities used by libp2p.
Package crypto implements various cryptographic utilities used by libp2p.
pb

Jump to