The highest tagged major version is
v3.
package
Version:
v2.4.0
Opens a new window with list of versions in this module.
Published: May 28, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
Cache 缓存对象
Add adds a value to the cache.
Clear purges all stored items from the cache.
Get looks up a key's value from the cache.
Len returns the number of items in the cache.
Remove removes the provided key from the cache.
func (c *Cache) RemoveOldest()
RemoveOldest removes the oldest item from the cache.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.